.. _install_section:

Installation
------------

To install `pyshortcuts`, use::

    pip install pyshortcuts


Pyshortcuts requires the `charset-normalizer` package.  On Windows, pyshortcuts
also requires the `pywin32` package.  Both of these will be installed if
needed.

To use the pyshortcut GUI, the wxPython package is required, which can be
installed with::

    pip install "pyshortcuts[gui]"

 For development versions, see  https://github.com/newville/pyshortcuts

Acknowledgments
--------------------

Pyshortcuts was originally written by Matthew Newville, The University of
Chicago. The code is developed at https://github.com/newville/pyshortcuts, and
distributed under the MIT license.
